Heka class

Constructors

Heka(String apiKey, String uuid)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
final

Methods

getAggregatedForType(HekaDataType type, DateTime start, DateTime end, HekaPlatform platform) Future<double?>
getDateWiseForType(HekaDataType type, DateTime start, DateTime end, HekaPlatform platform) Future<Map<DateTime, double>>
getMenstrualData({required DateTime startDate, required DateTime endDate, HekaPlatform? platform}) Future<List<MenstrualEntry>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAggregatedDataForIOS({required HekaDataType dataType, required DateTime startDate, required DateTime endDate}) Future<double?>