HekaConnectState class
- Annotations
-
- @freezed
Constructors
-
HekaConnectState({required bool isLoading, required String userUuid, required Map<
String, HekaPlatformState> platformStates, required String? paymentPlan, required bool loadingFailed}) -
constfactory
Properties
-
copyWith
→ $HekaConnectStateCopyWith<
HekaConnectState> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
no setterinherited
- loadingFailed → bool
-
no setterinherited
- paymentPlan → String?
-
no setterinherited
-
platformStates
→ Map<
String, HekaPlatformState> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userUuid → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited