Strava class
- Inheritance
-
- Object
- DataProvider
- Strava
Constructors
- Strava()
Properties
-
defaultScopes
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postConnect(
HekaHealth manager, String userUuid, DateTime? lastSyncDate) → Future< void> -
override
-
postDisconnect(
HekaHealth manager, String userUuid) → Future< void> -
override
-
preConnect(
HekaHealth manager, String userUuid) → Future< void> -
override
-
signIn(
HekaHealth manager, UserApp userApp) → Future< OAuth2Creds?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited