HekaHealthPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • HekaHealthPlatform
Implementers

Constructors

HekaHealthPlatform()
Constructs a HekaHealthPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<bool>
disconnect() Future<bool>
getAggregatedValueForDataType(String dataType, DateTime startDate, DateTime endDate) Future<double?>
getDateWiseData(String dataType, DateTime startDate, DateTime endDate) Future<Map<DateTime, double>>
getMenstrualData(DateTime startDate, DateTime endDate) Future<List<Object?>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestGoogleAuth() Future<bool>
requestHealthKitPermissions() Future<bool>
syncIosHealthData(String apiKey, String userUuid, DateTime? lastSyncDate) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance HekaHealthPlatform
The default instance of HekaHealthPlatform to use.
getter/setter pair