HekaHealth class

Constructors

HekaHealth(String _apiKey)

Properties

apiKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disconnect({required String userUuid, required String platform, String? deviceId}) Future<Either<HekaHealthError, Connection>>
fetchConnection(String userUuid) Future<Either<HekaHealthError, Connection?>>
getAggregatedDataFromServer({required String userUuid, required String platform, required String dataType, required DateTime startDate, required DateTime endDate}) Future<Either<HekaHealthError, double>>
getDateWiseData({required String userUuid, required String platform, required String dataType, required DateTime startDate, required DateTime endDate}) Future<Either<HekaHealthError, List<Map<String, dynamic>>>>
getMenstrualData({required String userUuid, required String platform, required DateTime startDate, required DateTime endDate}) Future<Either<HekaHealthError, List<Map>>>
loadAppAndConnection(String userUuid) Future<Either<HekaHealthError, HekaAppAndConnection>>
makeConnection({required String userUuid, required String platform, String? googleFitRefreshToken, String? emailId, String? deviceId}) Future<Either<HekaHealthError, Connection>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited